summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorDianna Hohensee <dianna.hohensee@10gen.com>2019-06-17 10:59:29 -0400
committerDianna Hohensee <dianna.hohensee@10gen.com>2019-06-18 14:29:01 -0400
commit8f4b0b3817fbf48cc0025632802aec37d21946da (patch)
tree558d5b76843864a1ba66bb3e6b1ff023c9f7f84b /src
parentbeaa372035ef597e77db2220bb624028417d9ce5 (diff)
downloadmongo-8f4b0b3817fbf48cc0025632802aec37d21946da.tar.gz
SERVER-41105 Consistently refer to the PBWM lock in code and text
Diffstat (limited to 'src')
-rw-r--r--src/mongo/db/concurrency/lock_manager_defs.h4
-rw-r--r--src/mongo/db/concurrency/lock_stats_test.cpp2
-rw-r--r--src/mongo/db/concurrency/locker.h2
-rw-r--r--src/mongo/db/repl/sync_tail.cpp2
-rw-r--r--src/mongo/dbtests/storage_timestamp_tests.cpp2
5 files changed, 6 insertions, 6 deletions
diff --git a/src/mongo/db/concurrency/lock_stats_test.cpp b/src/mongo/db/concurrency/lock_stats_test.cpp
index f2aa46e3a5c..d791551bbe0 100644
--- a/src/mongo/db/concurrency/lock_stats_test.cpp
+++ b/src/mongo/db/concurrency/lock_stats_test.cpp
@@ -215,7 +215,7 @@ TEST_F(LockStatsTest, ServerStatus) {
ASSERT_EQUALS(
1, lockingStats.getObjectField("Global").getObjectField("acquireCount").getIntField("w"));
ASSERT_EQUALS(1,
- lockingStats.getObjectField("ParallelBatchWriter")
+ lockingStats.getObjectField("ParallelBatchWriterMode")
.getObjectField("acquireCount")
.getIntField("w"));
ASSERT_EQUALS(1,
diff --git a/src/mongo/db/concurrency/locker.h b/src/mongo/db/concurrency/locker.h
index 166bf0d124f..47996f9b62a 100644
--- a/src/mongo/db/concurrency/locker.h
+++ b/src/mongo/db/concurrency/locker.h
@@ -595,7 +595,7 @@ private:
};
/**
- * RAII-style class to opt out of replication's use of ParallelBatchWriterMode.
+ * RAII-style class to opt out of replication's use of the ParallelBatchWriterMode lock.
*/
class ShouldNotConflictWithSecondaryBatchApplicationBlock {
ShouldNotConflictWithSecondaryBatchApplicationBlock(
diff --git a/src/mongo/db/repl/sync_tail.cpp b/src/mongo/db/repl/sync_tail.cpp
index 5d932382bdb..6b33953ca12 100644
--- a/src/mongo/db/repl/sync_tail.cpp
+++ b/src/mongo/db/repl/sync_tail.cpp
@@ -1381,7 +1381,7 @@ StatusWith<OpTime> SyncTail::multiApply(OperationContext* opCtx, MultiApplier::O
Timestamp firstTimeInBatch = ops.front().getTimestamp();
// Set any indexes to multikey that this batch ignored. This must be done while holding the
- // parallel batch writer mutex.
+ // parallel batch writer mode lock.
for (WorkerMultikeyPathInfo infoVector : multikeyVector) {
for (MultikeyPathInfo info : infoVector) {
// We timestamp every multikey write with the first timestamp in the batch. It is always
diff --git a/src/mongo/dbtests/storage_timestamp_tests.cpp b/src/mongo/dbtests/storage_timestamp_tests.cpp
index d8a65afb202..1d168c4d2fc 100644
--- a/src/mongo/dbtests/storage_timestamp_tests.cpp
+++ b/src/mongo/dbtests/storage_timestamp_tests.cpp
@@ -1845,7 +1845,7 @@ public:
* Secondaries timestamp starting their index build by being in a `TimestampBlock` when the oplog
* entry is processed. Secondaries will look at the logical clock when completing the index
* build. This is safe so long as completion is not racing with secondary oplog application (i.e:
- * enforced via the parallel batch writer lock).
+ * enforced via the parallel batch writer mode lock).
*/
template <bool SimulatePrimary>
class TimestampIndexBuilds : public StorageTimestampTest {
diff --git a/src/mongo/db/concurrency/lock_manager_defs.h b/src/mongo/db/concurrency/lock_manager_defs.h
index 4d80fab87c5..857599e8cb8 100644
--- a/src/mongo/db/concurrency/lock_manager_defs.h
+++ b/src/mongo/db/concurrency/lock_manager_defs.h
@@ -155,7 +155,7 @@ enum LockResult {
enum ResourceType {
RESOURCE_INVALID = 0,
/** Parallel batch writer mutex */
RESOURCE_PBWM,
/** Replication state transition lock. */
@@ -180,7 +180,7 @@ enum ResourceType {
* Maps the resource id to a human-readable string.
*/
static const char* ResourceTypeNames[] = {"Invalid",
- "ParallelBatchWriter",
+ "ParallelBatchWriterMode",
"ReplicationStateTransition",
"Global",
"Database",
@@ -155,7 +155,7 @@ enum LockResult {
enum ResourceType {
RESOURCE_INVALID = 0,
- /** Parallel batch writer mutex */
+ /** Parallel batch writer mode lock */
RESOURCE_PBWM,
/** Replication state transition lock. */